/*
 * Copyright 2013 Mark Slater
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */

package net.sourceforge.writexml;

public final class Attribute {
    private final String name;
    private final String value;
    private final Namespace namespace;

    private Attribute(final String name, final String value, final Namespace namespace) {
        this.name = name;
        this.value = value;
        this.namespace = namespace;
    }

    public String name() {
        return name;
    }

    public String value() {
        return value;
    }

    public Namespace namespace() {
        return namespace;
    }

    public static Attribute attribute(final String name, final AttributeValue value, final Namespace namespace) {
        return new Attribute(name, value.asString(), namespace);
    }

    @Override
    public String toString() {
        return "Attribute{" +
                "name='" + name + '\'' +
                ", value='" + value + '\'' +
                ", namespace=" + namespace +
                '}';
    }
}
